@@ -77,25 +77,26 @@ test_that("grouped intervals work", {
 
   vdiffr::expect_doppelganger("grouped intervals (stat)", stat_forward_plot)
 
-  stat_forward_plot_mode_hdi = RankCorr_u_tau %>%
-    ggplot(aes(x = i, y = u_tau)) +
-    stat_interval(.width = c(.5, .75, .90), point_interval = mode_hdi) +
-    scale_color_brewer()
+})
+
+test_that("multimodal intervals work with stat_interval", {
+  skip_if_not_installed("vdiffr")
+  skip_if_not_installed("svglite")
 
-  vdiffr::expect_doppelganger("grouped intervals (stat, mode_hdi)", stat_forward_plot_mode_hdi)
+  set.seed(1234)
+  df = data.frame(x = c(rnorm(300), rnorm(300, 5)) + c(0,.5), g = c("a","b"))
 
-  reverse_plot = RankCorr_u_tau %>%
-    mean_qi(.width = c(.90, .75, .5)) %>%
-    ggplot(aes(x = i, y = u_tau)) +
-    geom_interval() +
+  stat_intervalh_plot_multimodal_dodged = df %>%
+    ggplot(aes(x = x, y = "a", group = g)) +
+    stat_intervalh(point_interval = mean_hdi, position = ggstance::position_dodgev()) +
     scale_color_brewer()
 
-  vdiffr::expect_doppelganger("grouped intervals (reverse order)", reverse_plot)
+  vdiffr::expect_doppelganger("multimodal intervals (h, stat, dodged)", stat_intervalh_plot_multimodal_dodged)
 
-  stat_reverse_plot = RankCorr_u_tau %>%
-    ggplot(aes(x = i, y = u_tau)) +
-    stat_interval(.width = c(.90, .75, .5)) +
+  stat_interval_plot_multimodal_dodged = df %>%
+    ggplot(aes(y = x, x = "a", group = g)) +
+    stat_interval(point_interval = mean_hdi, position = "dodge") +
     scale_color_brewer()
 
-  vdiffr::expect_doppelganger("grouped intervals (stat, reverse order)", stat_reverse_plot)
+  vdiffr::expect_doppelganger("multimodal intervals (stat, dodged)", stat_interval_plot_multimodal_dodged)
 })
