@@ -31,7 +31,7 @@ test_that("[add_]predicted_draws throws an error on unsupported models", {
 
 test_that("[add_]predicted_draws and basic arguments works on a simple rstanarm model", {
   skip_if_not_installed("rstanarm")
-  m_hp_wt = readRDS("../models/models.rstanarm.m_hp_wt.rds")
+  m_hp_wt = readRDS(test_path("../models/models.rstanarm.m_hp_wt.rds"))
 
   preds = rstanarm::posterior_predict(m_hp_wt, mtcars_tbl, draws = 100, seed = 123) %>%
     as.data.frame() %>%
@@ -46,16 +46,17 @@ test_that("[add_]predicted_draws and basic arguments works on a simple rstanarm
   ref = mtcars_tbl %>%
     mutate(.row = rownames(.)) %>%
     inner_join(preds, by = ".row") %>%
-    mutate(.row = as.integer(.row))
+    mutate(.row = as.integer(.row)) %>%
+    group_by(mpg, cyl, disp, hp, drat, wt, qsec, vs, am, gear, carb, .row)
 
-  expect_equal(ref, predicted_draws(m_hp_wt, mtcars_tbl, n = 100, seed = 123))
-  expect_equal(ref, add_predicted_draws(mtcars_tbl, m_hp_wt, n = 100, seed = 123))
+  expect_equal(predicted_draws(m_hp_wt, mtcars_tbl, n = 100, seed = 123), ref)
+  expect_equal(add_predicted_draws(mtcars_tbl, m_hp_wt, n = 100, seed = 123), ref)
 })
 
 
 test_that("[add_]predicted_draws and basic arguments works on an rstanarm model with random effects", {
   skip_if_not_installed("rstanarm")
-  m_cyl = readRDS("../models/models.rstanarm.m_cyl.rds")
+  m_cyl = readRDS(test_path("../models/models.rstanarm.m_cyl.rds"))
 
   preds = rstanarm::posterior_predict(m_cyl, mtcars_tbl, draws = 100, seed = 123) %>%
     as.data.frame() %>%
@@ -70,16 +71,17 @@ test_that("[add_]predicted_draws and basic arguments works on an rstanarm model
   ref = mtcars_tbl %>%
     mutate(.row = rownames(.)) %>%
     inner_join(preds, by = ".row") %>%
-    mutate(.row = as.integer(.row))
+    mutate(.row = as.integer(.row)) %>%
+    group_by(mpg, cyl, disp, hp, drat, wt, qsec, vs, am, gear, carb, .row)
 
-  expect_equal(ref, predicted_draws(m_cyl, mtcars_tbl, n = 100, seed = 123))
-  expect_equal(ref, add_predicted_draws(mtcars_tbl, m_cyl, n = 100, seed = 123))
+  expect_equal(predicted_draws(m_cyl, mtcars_tbl, n = 100, seed = 123), ref)
+  expect_equal(add_predicted_draws(mtcars_tbl, m_cyl, n = 100, seed = 123), ref)
 })
 
 
 test_that("[add_]predicted_draws works on a simple brms model", {
   skip_if_not_installed("brms")
-  m_hp = readRDS("../models/models.brms.m_hp.rds")
+  m_hp = readRDS(test_path("../models/models.brms.m_hp.rds"))
 
   set.seed(123)
   preds = predict(m_hp, mtcars_tbl, summary = FALSE, nsamples = 100) %>%
@@ -96,7 +98,8 @@ test_that("[add_]predicted_draws works on a simple brms model", {
   ref = mtcars_tbl %>%
     mutate(.row = rownames(.)) %>%
     inner_join(preds, by = ".row") %>%
-    mutate(.row = as.integer(.row))
+    mutate(.row = as.integer(.row)) %>%
+    group_by(mpg, cyl, disp, hp, drat, wt, qsec, vs, am, gear, carb, .row)
 
   expect_equal(predicted_draws(m_hp, mtcars_tbl, n = 100, seed = 123), ref)
   expect_equal(add_predicted_draws(mtcars_tbl, m_hp, n = 100, seed = 123), ref)
@@ -104,7 +107,7 @@ test_that("[add_]predicted_draws works on a simple brms model", {
 
 test_that("[add_]predicted_draws works on brms models with categorical outcomes", {
   skip_if_not_installed("brms")
-  m_cyl_mpg = readRDS("../models/models.brms.m_cyl_mpg.rds")
+  m_cyl_mpg = readRDS(test_path("../models/models.brms.m_cyl_mpg.rds"))
 
   set.seed(1234)
   raw_preds = predict(m_cyl_mpg, mtcars_tbl, summary = FALSE, nsamples = 100)
@@ -127,6 +130,7 @@ test_that("[add_]predicted_draws works on brms models with categorical outcomes"
     mutate(.row = rownames(.)) %>%
     inner_join(preds, by = ".row") %>%
     mutate(.row = as.integer(.row)) %>%
+    select(mpg:.row, .chain, .iteration, .draw, everything()) %>%
     group_by(mpg, cyl, disp, hp, drat, wt, qsec, vs, am, gear, carb, .row)
 
   expect_equal(predicted_draws(m_cyl_mpg, mtcars_tbl, seed = 1234, n = 100), ref)
@@ -135,7 +139,7 @@ test_that("[add_]predicted_draws works on brms models with categorical outcomes"
 
 test_that("[add_]predicted_draws works on brms models with dirichlet responses", {
   skip_if_not_installed("brms")
-  m_dirich = readRDS("../models/models.brms.m_dirich.rds")
+  m_dirich = readRDS(test_path("../models/models.brms.m_dirich.rds"))
 
   set.seed(1234)
   grid = tibble(x = c("A", "B"))
@@ -151,14 +155,40 @@ test_that("[add_]predicted_draws works on brms models with dirichlet responses",
   ref = grid %>%
     mutate(.row = as.integer(rownames(.))) %>%
     inner_join(preds, by = ".row") %>%
+    select(x, .row, .chain, .iteration, .draw, .category, everything()) %>%
     group_by(x, .row, .category)
 
   expect_equal(predicted_draws(m_dirich, grid, seed = 1234, n = 100), ref)
 })
 
+test_that("[add_]predicted_draws works on brms models with multinomial responses", {
+  skip_if_not_installed("brms")
+  m_multinom = readRDS(test_path("../models/models.brms.m_multinom.rds"))
+
+  set.seed(1234)
+  # use a low number for total so there are some 0s
+  grid = tibble(total = c(10, 20))
+  preds = predict(m_multinom, grid, summary = FALSE, nsamples = 10) %>%
+    array2df(list(.draw = NA, .row = NA, .category = TRUE), label.x = ".prediction") %>%
+    mutate(
+      .chain = NA_integer_,
+      .iteration = NA_integer_,
+      .row = as.integer(.row),
+      .draw = as.integer(.draw)
+    )
+
+  ref = grid %>%
+    mutate(.row = as.integer(rownames(.))) %>%
+    inner_join(preds, by = ".row") %>%
+    select(total, .row, .chain, .iteration, .draw, .category, everything()) %>%
+    group_by(total, .row, .category)
+
+  expect_equal(predicted_draws(m_multinom, grid, seed = 1234, n = 10), ref)
+})
+
 test_that("[add_]predicted_draws throws an error when nsamples is called instead of n in brms", {
   skip_if_not_installed("brms")
-  m_hp = readRDS("../models/models.brms.m_hp.rds")
+  m_hp = readRDS(test_path("../models/models.brms.m_hp.rds"))
 
   expect_error(
     m_hp %>% predicted_draws(newdata = mtcars_tbl, nsamples = 100),
@@ -172,7 +202,7 @@ test_that("[add_]predicted_draws throws an error when nsamples is called instead
 
 test_that("[add_]predicted_draws throws an error when draws is called instead of n in rstanarm", {
   skip_if_not_installed("rstanarm")
-  m_hp_wt = readRDS("../models/models.rstanarm.m_hp_wt.rds")
+  m_hp_wt = readRDS(test_path("../models/models.rstanarm.m_hp_wt.rds"))
 
   expect_error(
     m_hp_wt %>% predicted_draws(newdata = mtcars_tbl, draws = 100),
@@ -186,7 +216,7 @@ test_that("[add_]predicted_draws throws an error when draws is called instead of
 
 test_that("[add_]predicted_draws throws an error when re.form is called instead of re_formula in rstanarm", {
   skip_if_not_installed("rstanarm")
-  m_hp_wt = readRDS("../models/models.rstanarm.m_hp_wt.rds")
+  m_hp_wt = readRDS(test_path("../models/models.rstanarm.m_hp_wt.rds"))
 
   expect_error(
     m_hp_wt %>% predicted_draws(newdata = mtcars_tbl, re.form = NULL),
